# Backward-compatibility shim — real module is salmalm.tools.tool_handlers
import warnings as _w

_w.warn("tool_handlers is a shim; use salmalm.tools.tool_handlers directly", DeprecationWarning, stacklevel=2)
import importlib as _importlib
import sys as _sys

_real = _importlib.import_module("salmalm.tools.tool_handlers")
_sys.modules[__name__] = _real



# Backward-compatibility shim — real module is salmalm.features.transcript_hygiene
import warnings as _w

_w.warn(
    "transcript_hygiene is a shim; use salmalm.features.transcript_hygiene directly", DeprecationWarning, stacklevel=2
)
import importlib as _importlib
import sys as _sys

_real = _importlib.import_module("salmalm.features.transcript_hygiene")
_sys.modules[__name__] = _real



# Backward-compatibility shim — real module is salmalm.tools.tools_common
import warnings as _w

_w.warn("tools_common is a shim; use salmalm.tools.tools_common directly", DeprecationWarning, stacklevel=2)
import importlib as _importlib
import sys as _sys

_real = _importlib.import_module("salmalm.tools.tools_common")
_sys.modules[__name__] = _real



# Backward-compatibility shim — real module is salmalm.core.llm_loop
import warnings as _w

_w.warn("llm_loop is a shim; use salmalm.core.llm_loop directly", DeprecationWarning, stacklevel=2)
import importlib as _importlib
import sys as _sys

_real = _importlib.import_module("salmalm.core.llm_loop")
_sys.modules[__name__] = _real
